@@ -8,14 +8,14 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Systemd;
-$Config::Model::Systemd::VERSION = '0.005';
+$Config::Model::Systemd::VERSION = '0.006';
 use 5.10.1;
 
 use Config::Model 2.083;
 
 1;
 
-# ABSTRACT: Edit and validate Systemd configuration files
+# ABSTRACT: Editor and validator for systemd configuration files
 
 __END__
 
@@ -25,11 +25,11 @@ __END__
 
 =head1 NAME
 
-Config::Model::Systemd - Edit and validate Systemd configuration files
+Config::Model::Systemd - Editor and validator for systemd configuration files
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =head1 SYNOPSIS
 
@@ -42,7 +42,7 @@ version 0.005
 =head1 DESCRIPTION
 
 This module provides a configuration editor for the configuration file
-of Systemd, i.e. all files in C<~/.config/systemd/user/> or all files
+of systemd, i.e. all files in C<~/.config/systemd/user/> or all files
 in C</etc/systemd/system/>
 
 Ok. I simplified. Actually, this module provides the configuration
